
.. blogpost::
    :title: Build winrandom on Windows
    :keywords: winrandom, pycrypto
    :date: 2016-07-07
    :categories: module, build

    Small extension needed by `pycrypto <https://pypi.python.org/pypi/pycrypto>`_
    and Windows. I `forked <https://github.com/sdpython/winrandom>`_ and I applied
    a couple of modifications (types, exceptions, module declaration)
    to build it for Python 3.5.
    More about about to build pycrypto on Windows:
    `Compiler les librairies Python sous Windows <https://makina-corpus.com/blog/metier/2016/compile_python_wheels_windows/compiler-les-librairies-python-sous-windows>`_.
    About pcrypto, see also:
    `PyCrypto-Wheels <https://github.com/sfbahr/PyCrypto-Wheels>`_.
